==> haskell-type-hint-0.1-9-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-type-hint.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: type-hint
version: 0.1
id: type-hint-0.1-BZHH0UJkhgC2RXAa9JWu8V
key: type-hint-0.1-BZHH0UJkhgC2RXAa9JWu8V
license: BSD-3-Clause
copyright: 2014 Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
maintainer: Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
author: Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
stability: experimental
homepage: https://github.com/mvv/type-hint
synopsis: Guide type inference with proxy values
description:
    This package provides '\''Proxy'\'' values for various types from the @base@
    library and functions to use these values as hints for type inference.
category: Phantom Types
abi: a1690a073063048303d9dcd1b01fdf89
exposed: True
exposed-modules:
    Type.Hint
import-dirs: /usr/lib/ghc-8.4.3/site-local/type-hint-0.1
library-dirs: /usr/lib/ghc-8.4.3/site-local/type-hint-0.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/type-hint-0.1
hs-libraries: HStype-hint-0.1-BZHH0UJkhgC2RXAa9JWu8V
depends:
    base-4.11.1.0
abi-depends: base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
haddock-interfaces: /usr/share/doc/haskell-type-hint/html/type-hint.haddock
haddock-html: /usr/share/doc/haskell-type-hint/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-type-hint-0.1-10-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-type-hint.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: type-hint
version: 0.1
id: type-hint-0.1-HP8tKFGSWNP9WW8dks9Xp0
key: type-hint-0.1-HP8tKFGSWNP9WW8dks9Xp0
license: BSD-3-Clause
copyright: 2014 Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
maintainer: Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
author: Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
stability: experimental
homepage: https://github.com/mvv/type-hint
synopsis: Guide type inference with proxy values
description:
    This package provides '\''Proxy'\'' values for various types from the @base@
    library and functions to use these values as hints for type inference.
category: Phantom Types
abi: 3a46c0a4c62177f58fe2f12416f35dad
exposed: True
exposed-modules:
    Type.Hint
import-dirs: /usr/lib/ghc-8.6.1/site-local/type-hint-0.1
library-dirs: /usr/lib/ghc-8.6.1/site-local/type-hint-0.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.6.1/type-hint-0.1
hs-libraries: HStype-hint-0.1-HP8tKFGSWNP9WW8dks9Xp0
depends:
    base-4.12.0.0
haddock-interfaces: /usr/share/doc/haskell-type-hint/html/type-hint.haddock
haddock-html: /usr/share/doc/haskell-type-hint/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
